//+------------------------------------------------------------------+
//|                                                 GT BB SINWIN.mq4 |
//|                      Copyright  2010, MetaQuotes Software Corp. |
//|                             http://www.mql4.com/ru/users/rustein |
//+------------------------------------------------------------------+
#define MAGIC  131313
//-------------------------------------------------------------------+
extern int    StopLoss          = 34;
extern int    TakeProfit        = 89;
extern int    Slippage          = 3;
//-------------------------------------------------------------------+
extern double Lots              = 0.1;
extern int    MaxLossTrade      = 8;
//+------------------------------------------------------------------+
extern int    BBPeriod          = 20;
extern int    BBDeviation       = 3;
extern int    BBPrice           = 0;  // 0=Close,1=Open,2=High,3=Low,4=Median,5=Typical,6=Weighted
//-------------------------------------------------------------------+
extern int    Shift             = 1;
//+------------------------------------------------------------------+
//| Calculate open positions                                         |
//+------------------------------------------------------------------+
int CalculateCurrentOrders(string symbol)
  {
   int buys=0,sells=0;
//----
   for(int i=0;i<OrdersTotal();i++)
     {
      if(OrderSelect(i,SELECT_BY_POS,MODE_TRADES)==false) break;
      if(OrderSymbol()==Symbol() && OrderMagicNumber()==MAGIC)
        {
         if(OrderType()==OP_BUY)  buys++;
         if(OrderType()==OP_SELL) sells++;
        }
     }
//---- return orders volume
   if(buys>0) return(buys);
   else       return(-sells);
  }
//+------------------------------------------------------------------+
//| Calculate optimal lot size                                       |
//+------------------------------------------------------------------+
double LotsOptimized()
  {
   double lot=Lots;
   int    orders=HistoryTotal();     // history orders total
   int    losses=0;                  // number of losses orders without a break
//---- select lot size
//---- calcuulate number of losses orders without a break
   if(OrdersTotal()>=0)
     {
      for(int i=orders-1;i>=0;i--)
        {
         if(OrderSelect(i,SELECT_BY_POS,MODE_HISTORY)==false) { Print("Error in history!"); break; }
         if(OrderSymbol()!=Symbol() || OrderType()>OP_SELL) continue;
         //----
         if(OrderProfit()>0) break;
         if(OrderProfit()<0) losses++;
        }
      if(losses==1) lot=NormalizeDouble(lot*2,1);
      if(losses==2) lot=NormalizeDouble(lot*4,1);
      if(losses==3) lot=NormalizeDouble(lot*8,1);
      if(losses==4) lot=NormalizeDouble(lot*16,1);
      if(losses==5) lot=NormalizeDouble(lot*32,1);
      if(losses==6) lot=NormalizeDouble(lot*64,1);
      if(losses==7) lot=NormalizeDouble(lot*128,1);
      if(losses==8) lot=NormalizeDouble(lot*256,1);
      if(losses==9) lot=NormalizeDouble(lot*512,1);
      if(losses==10) lot=NormalizeDouble(lot*1024,1);
      if(losses==11) lot=NormalizeDouble(lot*2048,1);
      if(losses==12) lot=NormalizeDouble(lot*4096,1);
      if(losses==13) lot=NormalizeDouble(lot*8192,1);
      if(losses>MaxLossTrade) lot=Lots;
     }
//---- return lot size
   if(lot<0.1) lot=0.1;
   return(lot);
  }
//+------------------------------------------------------------------+
//| Check for open order conditions                                  |
//+------------------------------------------------------------------+
void CheckForOpen()
  {
   double ma;
   int    res;
//---- go trading only for first tiks of new bar
   if(Volume[0]>1) return;
//--------------------------------------------------------------------+
      double BBup = iBands(NULL,0,BBPeriod,BBDeviation,0,BBPrice, MODE_UPPER,Shift);
      double BBlo = iBands(NULL,0,BBPeriod,BBDeviation,0,BBPrice, MODE_LOWER,Shift);  
//--------------------------------------------------------------------+
//---- buy conditions
     if(Ask > BBup)
     {
      res = OrderSend(Symbol(),OP_BUY,LotsOptimized(),Ask,Slippage,Ask-(StopLoss*Point),Ask+(TakeProfit*Point),"GT SINWIN",MAGIC,0,Green);
      return;        
     } 
//---- sell conditions
     if(Bid < BBlo)  
     {
      res = OrderSend(Symbol(),OP_SELL,LotsOptimized(),Bid,Slippage,Bid+(StopLoss*Point),Bid-(TakeProfit*Point),"GT SINWIN",MAGIC,0,Red);
      return;  
     }
//----
  }
//+------------------------------------------------------------------+
//| Start function                                                   |
//+------------------------------------------------------------------+
void start()
  {
//---- check for history and trading
   if(Bars<100 || IsTradeAllowed()==false) return;
//---- calculate open orders by current symbol
   if(CalculateCurrentOrders(Symbol())==0) CheckForOpen();
  }
//+------------------------------------------------------------------+
//|---------------------------// END //------------------------------|
//+------------------------------------------------------------------+